#!/usr/bin/perl

use strict;
use HSPC::WebDB;
use HSPC::MT::CCP::Constants qw(:trans_types);
use HSPC::MT::PluginConfig::PP;

use constant PLUGIN_ID   => 'CCard_Assist';
use constant TEMPLATE_ID => 'OP_Assist';

if (
	is_table_exists(table=>'vendor_pp_plugin')
	&& is_table_exists(table=>'ccp_plugin_assist')
	) {
	my $rows =
	  select_hashrows(q|
			SELECT
				vendor_pp_plugin.vendor_id as vendor_id,
				vendor_pp_plugin.plugin_id as plugin_id,
				vendor_pp_plugin.is_active as is_active,
				pp_plugin.title as title,
				vendor_pp_plugin.banner_text as banner_text,
				pp_plugin.poll_period as poll_period,
				pp_plugin.is_autopay_supported as is_autopay_supported,

				ccp_plugin_assist.plugin_id as assist_plugin_id,
				ccp_plugin_assist.vendor_id as assist_vendor_id,
				ccp_plugin_assist.merchant_id as merchant_id,
				ccp_plugin_assist.login as login,
				ccp_plugin_assist.passwd as passwd,
				ccp_plugin_assist.purchase_url as purchase_url,
				ccp_plugin_assist.result_url as result_url,
				ccp_plugin_assist.is_preauth_enabled as is_preauth_enabled,
				ccp_plugin_assist.prefix as prefix,
				ccp_plugin_assist.test_mode as test_mode,
				ccp_plugin_assist.test_response as test_response
			FROM
				vendor_pp_plugin, pp_plugin, ccp_plugin_assist
			WHERE
					vendor_pp_plugin.plugin_id = pp_plugin.id
					and
					vendor_pp_plugin.plugin_id = ccp_plugin_assist.plugin_id
					and
					vendor_pp_plugin.vendor_id = ccp_plugin_assist.vendor_id
					and
					vendor_pp_plugin.plugin_id = ?
		|, &PLUGIN_ID );

	foreach my $plugin (@$rows) {

		## is configured ?
		if ( $plugin->{merchant_id} && $plugin->{login} && $plugin->{passwd})
		{
			my $new_plugin = HSPC::MT::PluginConfig::PP->new();

			$new_plugin->vendor_id( $plugin->{vendor_id} );
			$new_plugin->is_active( $plugin->{is_active} );
			$new_plugin->plugin_type('PP');
			$new_plugin->name( $plugin->{title} );

			my $config = {
				merchant_id             => $plugin->{merchant_id},
				login                   => $plugin->{login},
				passwd                  => $plugin->{passwd},
				purchase_url            => $plugin->{purchase_url},
				result_url              => $plugin->{result_url},
				is_preauth_enabled      => $plugin->{is_preauth_enabled},
				prefix                  => $plugin->{prefix},
				test_mode               => $plugin->{test_mode},
				test_response           => $plugin->{test_response},
				check_status_period_min => $plugin->{poll_period} / 60,
				num_of_tries            => 5,
			};

			$new_plugin->config_data( $config );

			$new_plugin->template_id( &TEMPLATE_ID );

			$new_plugin->banner_text( $plugin->{banner_text} );

			$new_plugin->is_direct( $plugin->{is_autopay_supported} );
			$new_plugin->start_billing_trans( &SW_CCP_TRANS_TYPE_SALE );
			$new_plugin->save();

			if ($new_plugin->id()) {

				## upgrade orders payed by this plugin
				select_run(q|
					UPDATE
						ar_doc_rb, ar_doc
					SET
						ar_doc_rb.plugin_id = ?
					WHERE
						ar_doc_rb.ar_doc_id = ar_doc.ar_doc_id
						AND ar_doc.vendor = ?
						AND ar_doc_rb.plugin_id = ?|, $new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID );
				## Update TransLog
				select_run(q|
					UPDATE
						pp_trans_log, account
					SET
						pp_trans_log.plugin_id = ?
					WHERE
						pp_trans_log.account_no = account.account_no
						AND account.vendor = ?
						AND pp_trans_log.plugin_id = ?|, $new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID
				);
			}
		}
	}
	## upgrade resseler config
	select_run(
		q|UPDATE reseller_config_plugin SET plugin_id = ? WHERE plugin_id = ? |,
		&TEMPLATE_ID,
		&PLUGIN_ID
	);
}
